@@ -91,7 +91,7 @@ def import_lessons(
             logger.info("  Lesson part {}".format(i))
 
             # Get plain ids
-            teacher_id = int(el[0])
+            teacher_id = int(el[0]) if el[0] else 0
             subject_id = int(el[2])
             class_ids = untis_split_third(el[17], conv=int)
 
